# -*- ruby -*-
#encoding: utf-8

require 'pluggability'
require 'strelka/mixins'

require 'strelka/cms' unless defined?( Strelka::CMS )
require 'strelka/cms/page' unless defined?( Strelka::CMS::Page )


# An abstract base class for page filters in the Strelka CMS.
#
# A page filter replaces one or more placeholders with generated or altered
# content.
#
class Strelka::CMS::PageFilter
	extend Loggability,
	       Pluggability


	# Loggability API -- log to the deveiate logger
	log_to :strelka_cms

	# Pluggability API -- list the directories to search for plugins
	plugin_prefixes 'strelka/cms/pagefilter'


	#################################################################
	###	I N S T A N C E   M E T H O D S
	#################################################################

	def name
		self.log.warn "#name called from: \n%s" % [ caller(1).join("\n") ]
		"pagefilter"
	end


	### Export any static resources required by this filter to the given +output_dir+.
	def export_resources( output_dir )
		# No-op by default
	end


	### Process the +page+'s source with the filter and return the altered content.
	def process( source, page, index )
		raise NotImplementedError,
			"%s does not implement the #process method" % [ self.class.name ]
	end

end # class Strelka::CMS::PageFilter


